@@ -23,8 +23,9 @@ class AsyncHTTPClient(BaseHTTPClient):
     async def close(self):
         await self.__session.close()
 
-    async def request(self, url: str, json: list = []):
-        async with self.__session.post(url, json=json) as response:
+    async def request(self, service: str, func: str, parameters: list = []):
+        url = self.BASE + service + "/" + func
+        async with self.__session.post(url, json=parameters) as response:
             data = await response.json()
             try:
                 response.raise_for_status()
